@@ -11,8 +11,9 @@ import string
 
 from molmass import MassCalc, SanityError
 
-osso_c = osso.Context("maemo_periodic", "1.0", False)
+osso_c = osso.Context("maemo_periodic", "1.1", False)
 
+distro = 'chinook'
 
 #grupos clasicos
 c1=[3,11,19,37,55,87] #Alcalinos
@@ -43,8 +44,6 @@ global tref
 tref=298.0
 
 
-
-## Elements properties ##
 from listas import *
 
 
@@ -100,15 +99,14 @@ def elige_color(tipo,num):
 class MainWindow(hildon.Program):
 	
 
-
 	def __init__(self):
 		hildon.Program.__init__(self)
         
 		self.window = hildon.Window()
 		self.window.set_default_size(800, 480)
+		self.window.set_title('Periodic Table')
 		self.window.connect("destroy", gtk.main_quit)
 
-## Fullscreen signals
 		self.window.connect("key-press-event", self.on_key_press)
 		self.window.connect("window-state-event", self.on_window_state_change)
 		self.window_in_fullscreen = False 
@@ -124,6 +122,7 @@ class MainWindow(hildon.Program):
 		self.menubar1.show()
 
 		self.exit = gtk.MenuItem("Exit")
+		self.exit.set_size_request(-1, 45)
 		self.exit.show()
 		self.exit.connect("activate", gtk.main_quit)
 
@@ -131,22 +130,27 @@ class MainWindow(hildon.Program):
 		self.m_view=gtk.Menu()
 		self.m_view.show()
 		self.ver=gtk.MenuItem("View")
+		self.ver.set_size_request(-1, 45)
 		self.ver.show()
 		self.ver.set_submenu(self.m_view)
 		
 		self.sincol=gtk.MenuItem("Colorless")
+		self.sincol.set_size_request(-1, 45)
 		self.sincol.show()
 		self.sincol.connect("activate",self.on_view_cless)
 
 		self.grupo=gtk.MenuItem("Groups")
+		self.grupo.set_size_request(-1, 45)
 		self.grupo.show()
 		self.grupo.connect("activate",self.on_view_group)
 
 		self.clasic=gtk.MenuItem("Classic")
+		self.clasic.set_size_request(-1, 45)
 		self.clasic.show()
 		self.clasic.connect("activate",self.on_view_classic)
 
 		self.fisest=gtk.MenuItem("Phys.State")
+		self.fisest.set_size_request(-1, 45)
 		self.fisest.show()
 		self.fisest.connect("activate",self.on_view_fisest)
 
@@ -158,18 +162,21 @@ class MainWindow(hildon.Program):
 #Submenu Options
 
 		self.options=gtk.MenuItem("Options")
+		self.options.set_size_request(-1, 45)
 		self.options.show()
 		self.options.connect("activate", self.on_options)
 
 #Submenu Grafics
 
 		self.grafics=gtk.MenuItem("Graphics")
+		self.grafics.set_size_request(-1, 45)
 		self.grafics.show()
 		self.grafics.connect("activate", self.on_grafics)
 		
 #Submenu Calc
 
 		self.calc=gtk.MenuItem("Calc")
+		self.calc.set_size_request(-1, 45)
 		self.calc.show()
 		self.calc.connect("activate", self.on_calc)
 
@@ -177,14 +184,17 @@ class MainWindow(hildon.Program):
 		self.m_web=gtk.Menu()
 		self.m_web.show()
 		self.web=gtk.MenuItem("Web")
+		self.web.set_size_request(-1, 45)
 		self.web.show()
 		self.web.set_submenu(self.m_web)
 
 		self.conect=gtk.MenuItem("Connect to ...")
+		self.conect.set_size_request(-1, 45)
 		self.conect.show()
 		self.conect.connect("activate",self.on_web_conect)
 
 		self.query=gtk.MenuItem("Query...")
+		self.query.set_size_request(-1, 45)
 		self.query.show()
 		self.query.connect("activate", self.on_web_query)
 
@@ -196,14 +206,17 @@ class MainWindow(hildon.Program):
 		self.m_about=gtk.Menu()
 		self.m_about.show()
 		self.about=gtk.MenuItem("About")
+		self.about.set_size_request(-1, 45)
 		self.about.show()
 		self.about.set_submenu(self.m_about)
 
 		self.refs=gtk.MenuItem("References")
+		self.refs.set_size_request(-1, 45)
 		self.refs.show()
 		self.refs.connect("activate",self.on_about_refs)
 
 		self.credits=gtk.MenuItem("Credits")
+		self.credits.set_size_request(-1, 45)
 		self.credits.show()
 		self.credits.connect("activate",self.on_about_credits)
 
@@ -235,24 +248,27 @@ class MainWindow(hildon.Program):
 		global caja
 		caja=['']
 		for i in range(1,len(nom)):
-			self.alignment1 = gtk.Alignment(0.5, 0.5, 1, 1)
-			self.alignment1.show()
+			if distro == 'chinook':
+				pass
+			else:
+				self.alignment1 = gtk.Alignment(0.5, 0.5, 1, 1)
+				self.alignment1.show()
 
-			self.hbuttonbox1 = gtk.HButtonBox()
-			self.hbuttonbox1.set_size_request(37, 20)
-			self.hbuttonbox1.show()
-			self.hbuttonbox1.set_spacing(0)
-			self.hbuttonbox1.set_layout(gtk.BUTTONBOX_DEFAULT_STYLE)
+				self.hbuttonbox1 = gtk.HButtonBox()
+				self.hbuttonbox1.set_size_request(37, 20)
+				self.hbuttonbox1.show()
+				self.hbuttonbox1.set_spacing(0)
+				self.hbuttonbox1.set_layout(gtk.BUTTONBOX_EDGE)
 
 			self.button1 = gtk.Button()
 			boton.append(self.button1)
-			
-			boton[i].set_size_request(37, 20)
-			boton[i].set_border_width(1)
+
+			boton[i].set_size_request(38, 20)
+			boton[i].set_border_width(0)
 			boton[i].connect("clicked", self.on_click)
 
-
 			self.eventbox=gtk.EventBox()
+			self.eventbox.set_size_request(38, 20)
 			caja.append(self.eventbox)
 			boton[i].add(self.eventbox)
 			self.eventbox.show()
@@ -266,10 +282,12 @@ class MainWindow(hildon.Program):
 
 			boton[i].set_name(sim[i])
 			boton[i].show()
+			if distro == 'chinook':
+				pass
+			else:
+				self.hbuttonbox1.pack_start(boton[i], False, False, 0)
+				self.alignment1.add(self.hbuttonbox1)
 
-			self.hbuttonbox1.pack_start(boton[i])
-
-			self.alignment1.add(self.hbuttonbox1)
 			if i==1:
 				left=0
 				top=0
@@ -317,9 +335,10 @@ class MainWindow(hildon.Program):
 
 			right=left+1
 			bottom=top+1
-			self.table1.attach(self.alignment1, left, right, top, bottom, gtk.EXPAND|gtk.FILL, gtk.EXPAND|gtk.FILL, 0, 0)
-
-
+			if distro == 'chinook':
+				self.table1.attach(boton[i], left, right, top, bottom, gtk.EXPAND|gtk.FILL, gtk.EXPAND|gtk.FILL, 0, 0)
+			else:
+				self.table1.attach(self.alignment1, left, right, top, bottom, gtk.EXPAND|gtk.FILL, gtk.EXPAND|gtk.FILL, 0, 0)
 
 ## add table to main window
 
@@ -424,38 +443,148 @@ class AboutDialog:
 
 class MyDialog(MainWindow):
 
+#El titulo de mayor longitud tiene 25 caracteres; si se annade una propiedad ojo con esto.
+#En la ventana caben 54 caracteres
+
 	def __init__(MainWindow):
+		def scroll_to(x=0, y=0):
+			v = swin.get_vadjustment()
+			child_height = swin.child.child.size_request()[1]
+			new_adj = gtk.Adjustment(y, 0, child_height)
+			swin.set_vadjustment(new_adj)
+
+		def scroll_by(dx=0, dy=0):
+			v = swin.get_vadjustment()
+			new_y = min(v.upper, v.value + dy)
+#			print v.upper, v.value
+			scroll_to(0, new_y)
+#			print new_y
+
+# Los valores de 100 y -100 son los 'pixels' que avanza el scroll
+
+		def on_key_press(widget, event, *args):            
+			if event.keyval == gtk.keysyms.Down:
+				scroll_by(0, 100)
+			elif event.keyval == gtk.keysyms.Up:
+				scroll_by(0, -100)
+			elif event.keyval == gtk.keysyms.F6:
+				if win.win_in_fullscreen:
+					win.unfullscreen ()
+				else:
+					win.fullscreen ()
+    
+		def on_window_state_change(widget, event, *args):           
+			if event.new_window_state & gtk.gdk.WINDOW_STATE_FULLSCREEN:
+				win.win_in_fullscreen = True
+			else:
+				win.win_in_fullscreen = False
+
+
 		win = hildon.Window()
 		win.connect('destroy', gtk.Widget.destroy)
+		win.connect("key-press-event", on_key_press)
+		win.connect("window-state-event", on_window_state_change)
+		win.win_in_fullscreen = False 
 		nelem=sim.index(element)
 		win.set_title(nom[nelem])
 
+		notebook = gtk.Notebook()
+		notebook.set_tab_pos(gtk.POS_BOTTOM)
+		notebook.set_scrollable(False)
+		notebook.show()
+
 		swin = gtk.ScrolledWindow()
-		swin.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-		win.add(swin)
+		if distro == 'chinook':
+			hildon.hildon_helper_set_thumb_scrollbar(swin, True)
+		swin.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC)
+#		win.add(swin)
 		swin.show()
 
+		#Para poder alinear se necesita fuente monospace
+		etiqueta='<tt>'
 
-		etiqueta=''
 
 		for i in range(len(titulo)):
-			etiqueta+='<b><u>'+titulo[i]+':</u></b>'
+		
+			tit=titulo[i]
+		
 			if props[i][nelem] in [' ','-'] or len(props[i][nelem])<1:
-				etiqueta+=' N.a.'
+		
+				etiqueta+="<b><u>%25s:</u></b> Na\n" % tit	
 			else:
-				etiqueta+=' '+props[i][nelem]
-				if corresp[i]>=0: 
-					etiqueta+=' '+units[corresp[i]]
-			etiqueta+='\n'
-			
+		
+				if corresp[i]>=0: unids=units[corresp[i]]
+				else:	unids=''
+				#si tiene unidades no sera muy largo: no se considea sumar len(unids)+1
+				if len(props[i][nelem])<23: etiqueta+="<b><u>%25s:</u></b> %s %s\n" % (tit,props[i][nelem],unids)
+				else:
+					trozo=[]
+					resto=props[i][nelem]
+					corte=22
+					longitud=len(resto)-resto.count('>')*5.5
+				
+					while longitud>22:
+						while not resto[corte]==' ': corte-=1
+						corte+=1
+						trozo.append(resto[:corte])
+						resto=resto[corte:]
+						longitud=len(resto)-resto.count('>')*5.5
+						corte=22
+					trozo.append(resto)
+					etiqueta+="<b><u>%25s:</u></b> %s\n" % (tit,trozo[0])
+					
+					for i in range(1,len(trozo)): etiqueta+=' '*26+trozo[i]+'\n'
 
+					#En este caso no hara falta poner unidades
+					#etiqueta+=' '*28+trozo[-1]+unids+'\n'
+				
+			
+		etiqueta+='</tt>'
+			
+		
 		label = gtk.Label(etiqueta)
 		label.set_use_markup(True)
+		label.set_line_wrap(False)
 		swin.add_with_viewport(label)
-		label.set_justify(gtk.JUSTIFY_CENTER)
+		#Parece que es la justificacion por defecto pero por si acaso...
+		label.set_justify(gtk.JUSTIFY_LEFT)
 		label.show()
 
+		label54 = gtk.Label("Properties")
+		label54.set_padding(0, 0)
+		label54.show()
+
+		scrolledwindow2 = gtk.ScrolledWindow()
+		scrolledwindow2.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+		scrolledwindow2.show()
+		scrolledwindow2.set_shadow_type(gtk.SHADOW_IN)
+
+		isot_div = isot[int(num[nelem])].split(",")
+		etiqueta1='<tt>'
+		for i in range(len(isot_div)):
+			etiqueta01=str(isot_div[i])
+			etiqueta1+= "\n" +etiqueta01
+		
+		etiqueta1+='</tt>'
+		label2 = gtk.Label(etiqueta1)
+		label2.set_use_markup(True)
+		label2.set_line_wrap(False)
+		scrolledwindow2.add_with_viewport(label2)
+		label2.set_justify(gtk.JUSTIFY_LEFT)
+		label2.show()
+
+
+		label55 = gtk.Label("Natural Isotopes")
+		label55.set_padding(0, 0)
+		label55.show()
+
+		notebook.append_page(swin, label54)
+
+		notebook.append_page(scrolledwindow2, label55)
+
+		win.add(notebook)
 		win.show()
+		
 
 class MassMolecular(MainWindow):
 	def __init__(MainWindow):
@@ -529,12 +658,12 @@ class MassMolecular(MainWindow):
 		hbuttonbox1.set_border_width(2)
 		hbuttonbox1.set_layout(gtk.BUTTONBOX_END)
 
-		button1 = gtk.Button(label="Calculate", stock=gtk.STOCK_OK)
+		button1 = gtk.Button(label="Calculate")
 		button1.show()
 		button1.connect("clicked", on_calcular_clicked)
 		hbuttonbox1.pack_start(button1)
 
-		button2 = gtk.Button(label="Close", stock=gtk.STOCK_CLOSE)
+		button2 = gtk.Button(label="Close")
 		button2.show()
 		button2.connect("clicked", on_cerrar_clicked)
 		hbuttonbox1.pack_start(button2)
@@ -547,6 +676,31 @@ class MassMolecular(MainWindow):
 class GraficProps(MainWindow):
 	def __init__(MainWindow):
 
+		def save_png(widget):
+			file_dialog = hildon.FileChooserDialog(wgraf, gtk.FILE_CHOOSER_ACTION_SAVE)
+			file_dialog.set_default_response(gtk.RESPONSE_OK)
+
+			response = file_dialog.run()
+			if response == gtk.RESPONSE_OK:
+				x, y, w, h = dra1.get_allocation()
+				pix_buffer = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, False, 8, w, h)
+				pix_buffer.get_from_drawable(pixmap, pixmap.get_colormap(), 0, 0, 0, 0, w, h)
+				pix_buffer.save(file_dialog.get_filename(), "png")
+			file_dialog.destroy()
+
+				
+		def crea_pixmap(widget):
+			x, y, width, height = wgraf.get_allocation()
+
+			pixmap = gtk.gdk.Pixmap(dra1.window, width, height)
+			pixmap.draw_rectangle(dra1.get_style().white_gc,True, 0, 0, width, height)
+			return pixmap
+
+		def refoco(widget,event):
+			 x , y, width, height = event.area
+			 widget.window.draw_drawable(widget.get_style().fg_gc[gtk.STATE_NORMAL],pixmap, x, y, x, y, width, height)
+			
+
 		def ver_activo(combo):
 			model = combo.get_model()
 			active = combo.get_active()
@@ -561,19 +715,27 @@ class GraficProps(MainWindow):
 			oy=300
 			fy=50
 			
+			x, y, width, height = wgraf.get_allocation()
+			pixmap.draw_rectangle(dra1.get_style().white_gc,True, 0, 0, width, height)			
+			
 			gc.set_foreground(blanco)
 			gc.set_background(blanco)
 			dibujo.draw_rectangle(gc,True,0,0,700,350)
 			
 			gc.line_width=1
 			gc.line_style=0
-			
-			nprop=titulo.index(ver_activo(comboprop))
+
+
+			axe=ver_activo(comboprop)
+			nprop=titulo.index(axe)
+			axe='Graph '+axe
+			wgraf.set_title(axe)
 			nat_ini=sim.index(ver_activo(combode))
 			nat_fin=sim.index(ver_activo(comboa))
 			gc.set_foreground(negro)
 			txto.set_text(titulo[nprop])
-			dibujo.draw_layout(gc,250,15,txto)
+		
+			pixmap.draw_layout(gc,250,15,txto)
 			gc.set_foreground(gris)
 			gc.set_background(blanco)
 			if nat_ini>nat_fin:
@@ -581,47 +743,107 @@ class GraficProps(MainWindow):
 				nat_fin=nat_ini
 				nat_ini=aux
 			valores=[]
-		
+			maxy=-1e20
+			miny=1e20
 			for i in range(nat_ini, nat_fin+1):
 				try:
-					valores.append(float(props[nprop][i]))
+					aux=float(props[nprop][i])
+					valores.append(aux)
+					if aux>maxy: maxy=aux
+					if aux<miny: miny=aux
+						
 				
 				except:
 					try:
 						aux=props[nprop][i].split()
 						valores.append(float(aux[0]))
+						if float(aux[0])>maxy: maxy=float(aux[0])
+						if float(aux[0])<miny: miny=float(aux[0])
 				
 					except:
-						valores.append(0)
-			maxy=max(valores)
-			miny=min(valores)
+						valores.append('NA')
+		
+			if maxy==miny:
+				if maxy>0 :maxy=1.1*maxy
+				else: maxy=0.9
+				if miny>0 : miny=0.9*miny
+				else: miny=1.1*miny
+			
 			nat=nat_fin-nat_ini
 			sclx=(fx-ox)/nat
+		
 			scly=(oy-fy)/(maxy-miny)
+			
+				
 			dptos=[]
 			gc.set_foreground(tinta)
 			gc.line_width=3
 			for i in range(len(valores)):
-				axe=(ox+i*sclx,oy-(valores[i]-miny)*scly)
+				try:
+					axe=(ox+i*sclx,oy-(valores[i]-miny)*scly)
+				
+				except:
+					axe=(ox+i*sclx,'NA')
+					
 				dptos.append(axe)
-			dibujo.draw_lines(gc,dptos)
+		
+			ctd0=False
+			vale0=True
+			vale1=True
+			i=1
+			x0,y0=dptos[0]
+			try:
+				y0=int(y0)
+			except:
+				vale0=False
+			
+			while i<len(valores):
+				x1,y1=dptos[i]
+				try:
+					y1=int(y1)
+					vale1=True
+				except:
+					vale1=False
+				if vale0 and vale1:
+				
+					pixmap.draw_line(gc,x0,y0,x1,y1)
+					ctd0=True
+				elif vale0 and not vale1 and not ctd0:
+				
+					pixmap.draw_rectangle(gc,True,x0-3,y0-3,6,6)
+				elif not vale0 and vale1: ctd0=False
+				
+
+				vale0=vale1
+				x0,y0=x1,y1
+				i+=1
+			if not vale0 and vale1:
+			
+				pixmap.draw_rectangle(gc,True,x1-3,y1-3,6,6)
+			
+				
 			if nat>10: numm=10
 			else: numm=nat
 			y0=oy+10
 			y1=oy-10
 			gc.set_foreground(gris)
 			gc.line_width=1
-			dibujo.draw_line(gc, ox,oy,fx,oy)
-			dibujo.draw_line(gc, ox,oy,ox,fy)
+		
+			pixmap.draw_line(gc, ox,oy,fx,oy)
+		
+			pixmap.draw_line(gc, ox,oy,ox,fy)
 			gc.line_style=1
 			if corresp[nprop]>=0:
 				txto.set_text('['+units[corresp[nprop]]+']')
-				dibujo.draw_layout(gc,10,10,txto)
+			
+				pixmap.draw_layout(gc,10,10,txto)
 			for i in range(numm+1):
 				x=sclx*(i*nat/numm)+ox
 				txto.set_text(repr(int(nat_ini+i*nat/numm)))
-				dibujo.draw_line(gc,x,oy,x,fy)
-				dibujo.draw_layout(gc,x-10, oy+10, txto)
+			
+				pixmap.draw_line(gc,x,oy,x,fy)
+			
+				pixmap.draw_layout(gc,x-10, oy+10, txto)
 			inc=(maxy-miny)/10
 			x0=ox-10
 			x1=ox+10
@@ -630,24 +852,47 @@ class GraficProps(MainWindow):
 				aux=inc*i+miny
 				axe="%.2e" % aux
 				txto.set_text(axe)
-				dibujo.draw_line(gc,ox,y,fx,y)
-				dibujo.draw_layout(gc,x0-90,y-15,txto)
+			
+				pixmap.draw_line(gc,ox,y,fx,y)
+			
+				pixmap.draw_layout(gc,x0-90,y-15,txto)
+
+			#pintar el pixmap
+			x , y, width, height = wgraf.get_allocation()
+			dra1.window.draw_drawable(dra1.get_style().fg_gc[gtk.STATE_NORMAL],pixmap, x, y, x, y, width, height)
 			
 			pass
 		
 		wgraf = hildon.Window()
 		wgraf.connect('destroy', gtk.Widget.destroy)
-		wgraf.set_title(' ')
+		wgraf.set_title('Graphics')
+
 		
 		vbox1=gtk.VBox(False,3)
 	
 		dra1=gtk.DrawingArea()
 		dra1.show()
 		dra1.set_size_request(650,350)
-		
+
+		dra1.connect('expose_event',refoco)
+
+		menubar2 = gtk.Menu()
+		for child in menubar2.get_children():
+			child.reparent(menu)
+		wgraf.set_menu(menubar2)
+		menubar2.show()
+
+		save_menu = gtk.MenuItem("Save")
+		save_menu.set_size_request(-1, 45)
+		save_menu.show()
+		save_menu.connect("activate", save_png)
+		menubar2.append(save_menu)
+
 		vbox1.pack_start(dra1, True, True,0)
-		hbox1=gtk.HBox(False,5)
+		hbox1=gtk.HBox(False,0)
+
 		comboprop=gtk.combo_box_new_text()
+		comboprop.set_size_request(230,30)
 		for i in range(len(titulo)):
 			if graficable[i]:
 				comboprop.append_text(titulo[i])
@@ -659,35 +904,47 @@ class GraficProps(MainWindow):
 		label1.show()
 		hbox1.pack_start(label1,True,True,0)
 		combode=gtk.combo_box_new_text()
+		combode.set_size_request(80,30)
 		for i in range(1,len(sim)):
 			combode.append_text(sim[i])
 		combode.set_active(0)
 		combode.show()
 		hbox1.pack_start(combode,True,True,0)
 		label2=gtk.Label("To:")
-		label2.set_size_request(70,30)
+		label2.set_size_request(45,30)
 		label2.show()
-		hbox1.pack_start(label2,True,True,0)
+		hbox1.pack_start(label2,False,False,0)
 		comboa=gtk.combo_box_new_text()
+		comboa.set_size_request(80,30)
 		for i in range(1,len(sim)):
 			comboa.append_text(sim[i])
 		comboa.set_active(len(sim)-2)
 		comboa.show()
 		hbox1.pack_start(comboa,True,True,0)
-		boton=gtk.Button(label="Draw", stock=gtk.STOCK_OK)
+		boton=gtk.Button(label="Draw")
 		boton.set_size_request(80,40)
 		boton.show()
 		boton.connect("clicked", on_dibujar_clicked)
 		hbox1.pack_start(boton,True,True,0)
+		#boton salir
+		salir=gtk.Button(label="Close")
+	
+		salir.show()
+		salir.connect("clicked", lambda a: wgraf.destroy())
+		hbox1.pack_start(salir,True,True,0)
+
+		
 		vbox1.pack_start(hbox1,True,True,0)
 		wgraf.add(vbox1)
 		wgraf.show_all()
-	
+		
 		txto=dra1.create_pango_layout("")
 		dibujo=dra1.window
 		dibujo.show()
 		gc=dibujo.new_gc()
-	
+		
+		pixmap=crea_pixmap(dra1)
+				
 		colormap=gc.get_colormap()
 		blanco=colormap.alloc_color('white')
 		negro=colormap.alloc_color('black')
@@ -730,12 +987,12 @@ class Opciones(MainWindow):
 		hbuttonbox1.set_border_width(2)
 		hbuttonbox1.set_layout(gtk.BUTTONBOX_END)
 
-		button1 = gtk.Button(label="Aceptar", stock=gtk.STOCK_OK)
+		button1 = gtk.Button(label="Set")
 		button1.show()
 		button1.connect("clicked", on_aceptar_clicked)
 		hbuttonbox1.pack_start(button1)
 
-		button2 = gtk.Button(label="Close", stock=gtk.STOCK_CLOSE)
+		button2 = gtk.Button(label="Cancel")
 		button2.show()
 		button2.connect("clicked", on_cerrar_clicked)
 		hbuttonbox1.pack_start(button2)
@@ -758,7 +1015,6 @@ class WebConect(MainWindow):
 			dlg.destroy()
 
 
-		
 		comando="dbus-send --print-reply --dest=com.nokia.osso_browser /com/nokia/osso_browser/service com.nokia.osso_browser.load_url string:"
 	
 		dlg = gtk.Dialog(title='Web Connect...', parent=None, flags=gtk.DIALOG_MODAL | gtk.WIN_POS_CENTER)
@@ -782,12 +1038,12 @@ class WebConect(MainWindow):
 		hbuttonbox1.set_border_width(2)
 		hbuttonbox1.set_layout(gtk.BUTTONBOX_END)
 
-		button1 = gtk.Button(label="Aceptar", stock=gtk.STOCK_OK)
+		button1 = gtk.Button(label="Go")
 		button1.show()
 		button1.connect("clicked", on_aceptar_clicked)
 		hbuttonbox1.pack_start(button1)
 
-		button2 = gtk.Button(label="Close", stock=gtk.STOCK_CLOSE)
+		button2 = gtk.Button(label="Close")
 		button2.show()
 		button2.connect("clicked", on_cerrar_clicked)
 		hbuttonbox1.pack_start(button2)
@@ -835,7 +1091,7 @@ class WebQuery(MainWindow):
 		hbox1 = gtk.HBox(False, 8)
 		hbox1.set_border_width(4)
 		label1 = gtk.Label("Key :  ")
-		hbox1.pack_start(label1, True, True, 0)
+		hbox1.pack_start(label1, False, False, 1)
 		texto=gtk.Entry()
 		texto.set_text("")
 		texto.set_editable(True)
@@ -853,12 +1109,12 @@ class WebQuery(MainWindow):
 		hbuttonbox1.set_border_width(2)
 		hbuttonbox1.set_layout(gtk.BUTTONBOX_END)
 
-		button1 = gtk.Button(label="Aceptar", stock=gtk.STOCK_OK)
+		button1 = gtk.Button(label="Query")
 		button1.show()
 		button1.connect("clicked", on_aceptar_clicked)
 		hbuttonbox1.pack_start(button1)
 
-		button2 = gtk.Button(label="Close", stock=gtk.STOCK_CLOSE)
+		button2 = gtk.Button(label="Close")
 		button2.show()
 		button2.connect("clicked", on_cerrar_clicked)
 		hbuttonbox1.pack_start(button2)
